summaryrefslogtreecommitdiff
path: root/cmd
diff options
context:
space:
mode:
authorDaniel J Walsh <dwalsh@redhat.com>2017-12-15 16:58:36 -0500
committerAtomic Bot <atomic-devel@projectatomic.io>2017-12-18 16:46:05 +0000
commit5770dc2640c216525ab84031e3712fcc46b3b087 (patch)
tree8a1c5c4e4a6ce6a35a3767247623a62bfd698f77 /cmd
parentde3468e120d489d046c08dad72ba2262e222ccb1 (diff)
downloadpodman-5770dc2640c216525ab84031e3712fcc46b3b087.tar.gz
podman-5770dc2640c216525ab84031e3712fcc46b3b087.tar.bz2
podman-5770dc2640c216525ab84031e3712fcc46b3b087.zip
Rename all references to kpod to podman
The decision is in, kpod is going to be named podman. Signed-off-by: Daniel J Walsh <dwalsh@redhat.com> Closes: #145 Approved by: umohnani8
Diffstat (limited to 'cmd')
-rw-r--r--cmd/podman/README.md (renamed from cmd/kpod/README.md)8
-rw-r--r--cmd/podman/attach.go (renamed from cmd/kpod/attach.go)2
-rw-r--r--cmd/podman/common.go (renamed from cmd/kpod/common.go)0
-rw-r--r--cmd/podman/common_test.go (renamed from cmd/kpod/common_test.go)2
-rw-r--r--cmd/podman/create.go (renamed from cmd/kpod/create.go)2
-rw-r--r--cmd/podman/create_cli.go (renamed from cmd/kpod/create_cli.go)0
-rw-r--r--cmd/podman/create_cli_test.go (renamed from cmd/kpod/create_cli_test.go)0
-rw-r--r--cmd/podman/diff.go (renamed from cmd/kpod/diff.go)4
-rw-r--r--cmd/podman/docker/types.go (renamed from cmd/kpod/docker/types.go)0
-rw-r--r--cmd/podman/exec.go (renamed from cmd/kpod/exec.go)2
-rw-r--r--cmd/podman/export.go (renamed from cmd/kpod/export.go)0
-rw-r--r--cmd/podman/formats/formats.go (renamed from cmd/kpod/formats/formats.go)0
-rw-r--r--cmd/podman/formats/templates.go (renamed from cmd/kpod/formats/templates.go)0
-rw-r--r--cmd/podman/history.go (renamed from cmd/kpod/history.go)4
-rw-r--r--cmd/podman/images.go (renamed from cmd/kpod/images.go)4
-rw-r--r--cmd/podman/import.go (renamed from cmd/kpod/import.go)0
-rw-r--r--cmd/podman/info.go (renamed from cmd/kpod/info.go)6
-rw-r--r--cmd/podman/inspect.go (renamed from cmd/kpod/inspect.go)6
-rw-r--r--cmd/podman/kill.go (renamed from cmd/kpod/kill.go)0
-rw-r--r--cmd/podman/load.go (renamed from cmd/kpod/load.go)2
-rw-r--r--cmd/podman/login.go (renamed from cmd/kpod/login.go)0
-rw-r--r--cmd/podman/logout.go (renamed from cmd/kpod/logout.go)0
-rw-r--r--cmd/podman/logs.go (renamed from cmd/kpod/logs.go)6
-rw-r--r--cmd/podman/main.go (renamed from cmd/kpod/main.go)8
-rw-r--r--cmd/podman/mount.go (renamed from cmd/kpod/mount.go)6
-rw-r--r--cmd/podman/parse.go (renamed from cmd/kpod/parse.go)0
-rw-r--r--cmd/podman/pause.go (renamed from cmd/kpod/pause.go)2
-rw-r--r--cmd/podman/ps.go (renamed from cmd/kpod/ps.go)2
-rw-r--r--cmd/podman/pull.go (renamed from cmd/kpod/pull.go)0
-rw-r--r--cmd/podman/push.go (renamed from cmd/kpod/push.go)4
-rw-r--r--cmd/podman/rm.go (renamed from cmd/kpod/rm.go)2
-rw-r--r--cmd/podman/rmi.go (renamed from cmd/kpod/rmi.go)0
-rw-r--r--cmd/podman/run.go (renamed from cmd/kpod/run.go)0
-rw-r--r--cmd/podman/save.go (renamed from cmd/kpod/save.go)0
-rw-r--r--cmd/podman/spec.go (renamed from cmd/kpod/spec.go)0
-rw-r--r--cmd/podman/spec_test.go (renamed from cmd/kpod/spec_test.go)0
-rw-r--r--cmd/podman/start.go (renamed from cmd/kpod/start.go)2
-rw-r--r--cmd/podman/stats.go (renamed from cmd/kpod/stats.go)2
-rw-r--r--cmd/podman/stop.go (renamed from cmd/kpod/stop.go)2
-rw-r--r--cmd/podman/tag.go (renamed from cmd/kpod/tag.go)0
-rw-r--r--cmd/podman/top.go (renamed from cmd/kpod/top.go)4
-rw-r--r--cmd/podman/umount.go (renamed from cmd/kpod/umount.go)0
-rw-r--r--cmd/podman/unpause.go (renamed from cmd/kpod/unpause.go)2
-rw-r--r--cmd/podman/user.go (renamed from cmd/kpod/user.go)0
-rw-r--r--cmd/podman/version.go (renamed from cmd/kpod/version.go)4
-rw-r--r--cmd/podman/wait.go (renamed from cmd/kpod/wait.go)2
46 files changed, 45 insertions, 45 deletions
diff --git a/cmd/kpod/README.md b/cmd/podman/README.md
index 7a79e4893..6978b056a 100644
--- a/cmd/kpod/README.md
+++ b/cmd/podman/README.md
@@ -1,8 +1,8 @@
-# kpod - Simple debugging tool for pods and images
-kpod is a simple client only tool to help with debugging issues when daemons such as CRI runtime and the kubelet are not responding or
-failing. A shared API layer could be created to share code between the daemon and kpod. kpod does not require any daemon running. kpod
+# podman - Simple debugging tool for pods and images
+podman is a simple client only tool to help with debugging issues when daemons such as CRI runtime and the kubelet are not responding or
+failing. A shared API layer could be created to share code between the daemon and podman. podman does not require any daemon running. podman
utilizes the same underlying components that crio uses i.e. containers/image, container/storage, oci-runtime-tool/generate, runc or
-any other OCI compatible runtime. kpod shares state with crio and so has the capability to debug pods/images created by crio.
+any other OCI compatible runtime. podman shares state with crio and so has the capability to debug pods/images created by crio.
## Use cases
1. List pods.
diff --git a/cmd/kpod/attach.go b/cmd/podman/attach.go
index 700023abe..8c2c99fd5 100644
--- a/cmd/kpod/attach.go
+++ b/cmd/podman/attach.go
@@ -20,7 +20,7 @@ var (
Usage: "Do not attach STDIN. The default is false.",
},
}
- attachDescription = "The kpod attach command allows you to attach to a running container using the container's ID or name, either to view its ongoing output or to control it interactively."
+ attachDescription = "The podman attach command allows you to attach to a running container using the container's ID or name, either to view its ongoing output or to control it interactively."
attachCommand = cli.Command{
Name: "attach",
Usage: "Attach to a running container",
diff --git a/cmd/kpod/common.go b/cmd/podman/common.go
index 99685107b..99685107b 100644
--- a/cmd/kpod/common.go
+++ b/cmd/podman/common.go
diff --git a/cmd/kpod/common_test.go b/cmd/podman/common_test.go
index 8a3bfd181..042568d7e 100644
--- a/cmd/kpod/common_test.go
+++ b/cmd/podman/common_test.go
@@ -12,7 +12,7 @@ import (
func TestGetStore(t *testing.T) {
t.Skip("FIX THIS!")
- //cmd/kpod/common_test.go:27: cannot use c (type *cli.Context) as type *libkpod.Config in argument to getStore
+ //cmd/podman/common_test.go:27: cannot use c (type *cli.Context) as type *libkpod.Config in argument to getStore
// Make sure the tests are running as root
skipTestIfNotRoot(t)
diff --git a/cmd/kpod/create.go b/cmd/podman/create.go
index afed70eaa..f65bc49c6 100644
--- a/cmd/kpod/create.go
+++ b/cmd/podman/create.go
@@ -128,7 +128,7 @@ type createConfig struct {
var createDescription = "Creates a new container from the given image or" +
" storage and prepares it for running the specified command. The" +
" container ID is then printed to stdout. You can then start it at" +
- " any time with the kpod start <container_id> command. The container" +
+ " any time with the podman start <container_id> command. The container" +
" will be created with the initial state 'created'."
var createCommand = cli.Command{
diff --git a/cmd/kpod/create_cli.go b/cmd/podman/create_cli.go
index 0cc265e92..0cc265e92 100644
--- a/cmd/kpod/create_cli.go
+++ b/cmd/podman/create_cli.go
diff --git a/cmd/kpod/create_cli_test.go b/cmd/podman/create_cli_test.go
index 63a1e5dd3..63a1e5dd3 100644
--- a/cmd/kpod/create_cli_test.go
+++ b/cmd/podman/create_cli_test.go
diff --git a/cmd/kpod/diff.go b/cmd/podman/diff.go
index 3a3b82e15..a3ca9ae50 100644
--- a/cmd/kpod/diff.go
+++ b/cmd/podman/diff.go
@@ -5,7 +5,7 @@ import (
"github.com/containers/storage/pkg/archive"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/urfave/cli"
)
@@ -79,7 +79,7 @@ func diffCmd(c *cli.Context) error {
}
if len(c.Args()) != 1 {
- return errors.Errorf("container, image, or layer name must be specified: kpod diff [options [...]] ID-NAME")
+ return errors.Errorf("container, image, or layer name must be specified: podman diff [options [...]] ID-NAME")
}
runtime, err := getRuntime(c)
diff --git a/cmd/kpod/docker/types.go b/cmd/podman/docker/types.go
index a7e456554..a7e456554 100644
--- a/cmd/kpod/docker/types.go
+++ b/cmd/podman/docker/types.go
diff --git a/cmd/kpod/exec.go b/cmd/podman/exec.go
index f76983810..0b3b9504d 100644
--- a/cmd/kpod/exec.go
+++ b/cmd/podman/exec.go
@@ -29,7 +29,7 @@ var (
},
}
execDescription = `
- kpod exec
+ podman exec
Run a command in a running container
`
diff --git a/cmd/kpod/export.go b/cmd/podman/export.go
index 9b498562e..9b498562e 100644
--- a/cmd/kpod/export.go
+++ b/cmd/podman/export.go
diff --git a/cmd/kpod/formats/formats.go b/cmd/podman/formats/formats.go
index 4b6527b30..4b6527b30 100644
--- a/cmd/kpod/formats/formats.go
+++ b/cmd/podman/formats/formats.go
diff --git a/cmd/kpod/formats/templates.go b/cmd/podman/formats/templates.go
index c2582552a..c2582552a 100644
--- a/cmd/kpod/formats/templates.go
+++ b/cmd/podman/formats/templates.go
diff --git a/cmd/kpod/history.go b/cmd/podman/history.go
index 20422b7c3..f142f5fd4 100644
--- a/cmd/kpod/history.go
+++ b/cmd/podman/history.go
@@ -10,7 +10,7 @@ import (
units "github.com/docker/go-units"
"github.com/opencontainers/image-spec/specs-go/v1"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/urfave/cli"
)
@@ -99,7 +99,7 @@ func historyCmd(c *cli.Context) error {
return errors.Errorf("an image name must be specified")
}
if len(args) > 1 {
- return errors.Errorf("Kpod history takes at most 1 argument")
+ return errors.Errorf("podman history takes at most 1 argument")
}
imgName := args[0]
diff --git a/cmd/kpod/images.go b/cmd/podman/images.go
index 2b1003ebd..90dd8ae12 100644
--- a/cmd/kpod/images.go
+++ b/cmd/podman/images.go
@@ -10,7 +10,7 @@ import (
"github.com/docker/go-units"
digest "github.com/opencontainers/go-digest"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/projectatomic/libpod/libpod/common"
"github.com/urfave/cli"
@@ -107,7 +107,7 @@ func imagesCmd(c *cli.Context) error {
imageInput = c.Args().Get(0)
}
if len(c.Args()) > 1 {
- return errors.New("'kpod images' requires at most 1 argument")
+ return errors.New("'podman images' requires at most 1 argument")
}
params, err := runtime.ParseImageFilter(imageInput, c.String("filter"))
diff --git a/cmd/kpod/import.go b/cmd/podman/import.go
index 2e8702c3d..2e8702c3d 100644
--- a/cmd/kpod/import.go
+++ b/cmd/podman/import.go
diff --git a/cmd/kpod/info.go b/cmd/podman/info.go
index c491b4585..89f32a258 100644
--- a/cmd/kpod/info.go
+++ b/cmd/podman/info.go
@@ -4,7 +4,7 @@ import (
"runtime"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/urfave/cli"
)
@@ -14,7 +14,7 @@ var (
infoCommand = cli.Command{
Name: "info",
Usage: infoDescription,
- Description: `Information display here pertain to the host, current storage stats, and build of kpod. Useful for the user and when reporting issues.`,
+ Description: `Information display here pertain to the host, current storage stats, and build of podman. Useful for the user and when reporting issues.`,
Flags: infoFlags,
Action: infoCmd,
ArgsUsage: "",
@@ -78,7 +78,7 @@ func debugInfo(c *cli.Context) map[string]interface{} {
info := map[string]interface{}{}
info["compiler"] = runtime.Compiler
info["go version"] = runtime.Version()
- info["kpod version"] = c.App.Version
+ info["podman version"] = c.App.Version
info["git commit"] = gitCommit
return info
}
diff --git a/cmd/kpod/kill.go b/cmd/podman/kill.go
index 776c7ef20..776c7ef20 100644
--- a/cmd/kpod/kill.go
+++ b/cmd/podman/kill.go
diff --git a/cmd/kpod/load.go b/cmd/podman/load.go
index 5ae75a7a2..2f3d9c56d 100644
--- a/cmd/kpod/load.go
+++ b/cmd/podman/load.go
@@ -69,7 +69,7 @@ func loadCmd(c *cli.Context) error {
}
// checking if loading from pipe
if !fi.Mode().IsRegular() {
- outFile, err := ioutil.TempFile("/var/tmp", "kpod")
+ outFile, err := ioutil.TempFile("/var/tmp", "podman")
if err != nil {
return errors.Errorf("error creating file %v", err)
}
diff --git a/cmd/kpod/login.go b/cmd/podman/login.go
index 8984d069c..8984d069c 100644
--- a/cmd/kpod/login.go
+++ b/cmd/podman/login.go
diff --git a/cmd/kpod/logout.go b/cmd/podman/logout.go
index cae8ddfb2..cae8ddfb2 100644
--- a/cmd/kpod/logout.go
+++ b/cmd/podman/logout.go
diff --git a/cmd/kpod/logs.go b/cmd/podman/logs.go
index 726ba4a65..8745d5d7f 100644
--- a/cmd/kpod/logs.go
+++ b/cmd/podman/logs.go
@@ -38,8 +38,8 @@ var (
Usage: "Output the specified number of LINES at the end of the logs. Defaults to 0, which prints all lines",
},
}
- logsDescription = "The kpod logs command batch-retrieves whatever logs are present for a container at the time of execution. This does not guarantee execution" +
- "order when combined with kpod run (i.e. your run may not have generated any logs at the time you execute kpod logs"
+ logsDescription = "The podman logs command batch-retrieves whatever logs are present for a container at the time of execution. This does not guarantee execution" +
+ "order when combined with podman run (i.e. your run may not have generated any logs at the time you execute podman logs"
logsCommand = cli.Command{
Name: "logs",
Usage: "Fetch the logs of a container",
@@ -63,7 +63,7 @@ func logsCmd(c *cli.Context) error {
args := c.Args()
if len(args) != 1 {
- return errors.Errorf("'kpod logs' requires exactly one container name/ID")
+ return errors.Errorf("'podman logs' requires exactly one container name/ID")
}
sinceTime := time.Time{}
diff --git a/cmd/kpod/main.go b/cmd/podman/main.go
index a2a81c8b6..cc6d26992 100644
--- a/cmd/kpod/main.go
+++ b/cmd/podman/main.go
@@ -13,7 +13,7 @@ import (
// This is populated by the Makefile from the VERSION file
// in the repository
-var kpodVersion = ""
+var podmanVersion = ""
func main() {
debug := false
@@ -24,12 +24,12 @@ func main() {
}
app := cli.NewApp()
- app.Name = "kpod"
+ app.Name = "podman"
app.Usage = "manage pods and images"
var v string
- if kpodVersion != "" {
- v = kpodVersion
+ if podmanVersion != "" {
+ v = podmanVersion
}
app.Version = v
diff --git a/cmd/kpod/mount.go b/cmd/podman/mount.go
index e90f54537..9db27fcda 100644
--- a/cmd/kpod/mount.go
+++ b/cmd/podman/mount.go
@@ -5,16 +5,16 @@ import (
"fmt"
"github.com/pkg/errors"
- of "github.com/projectatomic/libpod/cmd/kpod/formats"
+ of "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/urfave/cli"
)
var (
mountDescription = `
- kpod mount
+ podman mount
Lists all mounted containers mount points
- kpod mount CONTAINER-NAME-OR-ID
+ podman mount CONTAINER-NAME-OR-ID
Mounts the specified container and outputs the mountpoint
`
diff --git a/cmd/kpod/parse.go b/cmd/podman/parse.go
index 53d49c36c..53d49c36c 100644
--- a/cmd/kpod/parse.go
+++ b/cmd/podman/parse.go
diff --git a/cmd/kpod/pause.go b/cmd/podman/pause.go
index dede89443..cd581b08f 100644
--- a/cmd/kpod/pause.go
+++ b/cmd/podman/pause.go
@@ -10,7 +10,7 @@ import (
var (
pauseDescription = `
- kpod pause
+ podman pause
Pauses one or more running containers. The container name or ID can be used.
`
diff --git a/cmd/kpod/ps.go b/cmd/podman/ps.go
index 6b807671e..c674c9d1e 100644
--- a/cmd/kpod/ps.go
+++ b/cmd/podman/ps.go
@@ -13,7 +13,7 @@ import (
"github.com/docker/go-units"
specs "github.com/opencontainers/runtime-spec/specs-go"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/urfave/cli"
"k8s.io/apimachinery/pkg/fields"
diff --git a/cmd/kpod/pull.go b/cmd/podman/pull.go
index 5726b20f1..5726b20f1 100644
--- a/cmd/kpod/pull.go
+++ b/cmd/podman/pull.go
diff --git a/cmd/kpod/push.go b/cmd/podman/push.go
index d3d42e0ee..69d6e6629 100644
--- a/cmd/kpod/push.go
+++ b/cmd/podman/push.go
@@ -64,7 +64,7 @@ var (
pushDescription = fmt.Sprintf(`
Pushes an image to a specified location.
The Image "DESTINATION" uses a "transport":"details" format.
- See kpod-push(1) section "DESTINATION" for the expected format`)
+ See podman-push(1) section "DESTINATION" for the expected format`)
pushCommand = cli.Command{
Name: "push",
@@ -81,7 +81,7 @@ func pushCmd(c *cli.Context) error {
args := c.Args()
if len(args) < 2 {
- return errors.New("kpod push requires exactly 2 arguments")
+ return errors.New("podman push requires exactly 2 arguments")
}
if err := validateFlags(c, pushFlags); err != nil {
return err
diff --git a/cmd/kpod/rm.go b/cmd/podman/rm.go
index 2f767457f..dcb8fac57 100644
--- a/cmd/kpod/rm.go
+++ b/cmd/podman/rm.go
@@ -23,7 +23,7 @@ var (
rmDescription = "Remove one or more containers"
rmCommand = cli.Command{
Name: "rm",
- Usage: fmt.Sprintf(`kpod rm will remove one or more containers from the host. The container name or ID can be used.
+ Usage: fmt.Sprintf(`podman rm will remove one or more containers from the host. The container name or ID can be used.
This does not remove images. Running containers will not be removed without the -f option.`),
Description: rmDescription,
Flags: rmFlags,
diff --git a/cmd/kpod/rmi.go b/cmd/podman/rmi.go
index 1b4cb7390..1b4cb7390 100644
--- a/cmd/kpod/rmi.go
+++ b/cmd/podman/rmi.go
diff --git a/cmd/kpod/run.go b/cmd/podman/run.go
index 6142983ad..6142983ad 100644
--- a/cmd/kpod/run.go
+++ b/cmd/podman/run.go
diff --git a/cmd/kpod/save.go b/cmd/podman/save.go
index 85a8c7930..85a8c7930 100644
--- a/cmd/kpod/save.go
+++ b/cmd/podman/save.go
diff --git a/cmd/kpod/spec.go b/cmd/podman/spec.go
index adfdf7347..adfdf7347 100644
--- a/cmd/kpod/spec.go
+++ b/cmd/podman/spec.go
diff --git a/cmd/kpod/spec_test.go b/cmd/podman/spec_test.go
index 01e1a4ad3..01e1a4ad3 100644
--- a/cmd/kpod/spec_test.go
+++ b/cmd/podman/spec_test.go
diff --git a/cmd/kpod/start.go b/cmd/podman/start.go
index 88dadb1c8..33bc354bb 100644
--- a/cmd/kpod/start.go
+++ b/cmd/podman/start.go
@@ -28,7 +28,7 @@ var (
},
}
startDescription = `
- kpod start
+ podman start
Starts one or more containers. The container name or ID can be used.
`
diff --git a/cmd/kpod/stats.go b/cmd/podman/stats.go
index d98c2ee27..cf54a8bfe 100644
--- a/cmd/kpod/stats.go
+++ b/cmd/podman/stats.go
@@ -9,7 +9,7 @@ import (
tm "github.com/buger/goterm"
"github.com/docker/go-units"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/urfave/cli"
)
diff --git a/cmd/kpod/stop.go b/cmd/podman/stop.go
index f18fbc232..3b1ffbba5 100644
--- a/cmd/kpod/stop.go
+++ b/cmd/podman/stop.go
@@ -24,7 +24,7 @@ var (
},
}
stopDescription = `
- kpod stop
+ podman stop
Stops one or more running containers. The container name or ID can be used.
A timeout to forcibly stop the container can also be set but defaults to 10
diff --git a/cmd/kpod/tag.go b/cmd/podman/tag.go
index f29c8c182..f29c8c182 100644
--- a/cmd/kpod/tag.go
+++ b/cmd/podman/tag.go
diff --git a/cmd/kpod/top.go b/cmd/podman/top.go
index 0c1eabbdb..796b31c1d 100644
--- a/cmd/kpod/top.go
+++ b/cmd/podman/top.go
@@ -6,7 +6,7 @@ import (
"strings"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/urfave/cli"
)
@@ -19,7 +19,7 @@ var (
},
}
topDescription = `
- kpod top
+ podman top
Display the running processes of the container.
`
diff --git a/cmd/kpod/umount.go b/cmd/podman/umount.go
index 4b6aba99e..4b6aba99e 100644
--- a/cmd/kpod/umount.go
+++ b/cmd/podman/umount.go
diff --git a/cmd/kpod/unpause.go b/cmd/podman/unpause.go
index 6deed7e77..a7ef65f85 100644
--- a/cmd/kpod/unpause.go
+++ b/cmd/podman/unpause.go
@@ -10,7 +10,7 @@ import (
var (
unpauseDescription = `
- kpod unpause
+ podman unpause
Unpauses one or more running containers. The container name or ID can be used.
`
diff --git a/cmd/kpod/user.go b/cmd/podman/user.go
index 3e2e308c5..3e2e308c5 100644
--- a/cmd/kpod/user.go
+++ b/cmd/podman/user.go
diff --git a/cmd/kpod/wait.go b/cmd/podman/wait.go
index 6e22f54e5..27cfecac9 100644
--- a/cmd/kpod/wait.go
+++ b/cmd/podman/wait.go
@@ -10,7 +10,7 @@ import (
var (
waitDescription = `
- kpod wait
+ podman wait
Block until one or more containers stop and then print their exit codes
`
diff --git a/cmd/kpod/inspect.go b/cmd/podman/inspect.go
index 3f9da8d83..7fd039b75 100644
--- a/cmd/kpod/inspect.go
+++ b/cmd/podman/inspect.go
@@ -5,7 +5,7 @@ import (
specs "github.com/opencontainers/runtime-spec/specs-go"
"github.com/pkg/errors"
- "github.com/projectatomic/libpod/cmd/kpod/formats"
+ "github.com/projectatomic/libpod/cmd/podman/formats"
"github.com/projectatomic/libpod/libpod"
"github.com/sirupsen/logrus"
"github.com/urfave/cli"
@@ -47,7 +47,7 @@ var (
func inspectCmd(c *cli.Context) error {
args := c.Args()
if len(args) == 0 {
- return errors.Errorf("container or image name must be specified: kpod inspect [options [...]] name")
+ return errors.Errorf("container or image name must be specified: podman inspect [options [...]] name")
}
if len(args) > 1 {
return errors.Errorf("too many arguments specified")
@@ -269,7 +269,7 @@ func getCgroup(spec *specs.Spec) string {
return cgroup
}
// ContainerData holds the kpod inspect data for a container
type ContainerData struct {
CtrInspectData *libpod.ContainerInspectData `json:"CtrInspectData"`
HostConfig *HostConfig `json:"HostConfig"`
@@ -269,7 +269,7 @@ func getCgroup(spec *specs.Spec) string {
return cgroup
}
-// ContainerData holds the kpod inspect data for a container
+// ContainerData holds the podman inspect data for a container
type ContainerData struct {
CtrInspectData *libpod.ContainerInspectData `json:"CtrInspectData"`
diff --git a/cmd/kpod/version.go b/cmd/podman/version.go
index 586c41da6..be9b406e7 100644
--- a/cmd/kpod/version.go
+++ b/cmd/podman/version.go
@@ -40,9 +40,9 @@ func versionCmd(c *cli.Context) error {
return nil
}
// Cli command to print out the full version of kpod
var versionCommand = cli.Command{
Name: "version",
- Usage: "Display the KPOD Version Information",
+ Usage: "Display the PODMAN Version Information",
Action: versionCmd,
}
@@ -40,9 +40,9 @@ func versionCmd(c *cli.Context) error {
return nil
}
-// Cli command to print out the full version of kpod
+// Cli command to print out the full version of podman
var versionCommand = cli.Command{
Name: "version",